@@ -21,6 +21,7 @@
 #include <unistd.h>
 #include <errno.h>
 #include <string.h>
+#include <dirent.h>
 
 #include "libbridge.h"
 #include "libbridge_private.h"
@@ -206,9 +207,8 @@ int br_foreach_port(const char *brname,
 {
 #ifdef HAVE_LIBSYSFS
 	struct sysfs_class_device *dev;
-	struct sysfs_directory *dir;
-	struct sysfs_link *plink;
-	struct dlist *links;
+	DIR *dir;
+	struct dirent *dirent;
 	int err = 0;
 	char path[SYSFS_PATH_MAX];
 
@@ -219,8 +219,8 @@ int br_foreach_port(const char *brname,
 	snprintf(path, sizeof(path), "%s/%s", 
 		 dev->path, SYSFS_BRIDGE_PORT_SUBDIR);
 
-	dprintf("path=%s\n", path);
-	dir = sysfs_open_directory(path);
+
+	dir = opendir(path);
 	if (!dir) {
 		/* no /sys/class/net/ethX/brif subdirectory
 		 * either: old kernel, or not really a bridge
@@ -228,20 +228,18 @@ int br_foreach_port(const char *brname,
 		goto old;
 	}
 
-	links = sysfs_get_dir_links(dir);
-	if (!links) {
-		err = -ENOSYS;
-		goto out;
-	}
-
 	err = 0;
-	dlist_for_each_data(links, plink, struct sysfs_link) {
+	while ((dirent = readdir(dir)) != NULL) {
+		if (0 == strcmp(dirent->d_name, "."))
+			 continue;
+		if (0 == strcmp(dirent->d_name, ".."))
+			continue;
 		++err;
-		if (iterator(brname, plink->name, arg))
+		if (iterator(brname, dirent->d_name, arg))
 			break;
 	}
- out:
-	sysfs_close_directory(dir);
+	closedir(dir);
+
 	return err;
 
  old:
